import { useState, useEffect } from 'react';
import { GalleryImage } from '../../types';
import { GalleryGrid } from './GalleryGrid';
import { ImageForm } from './ImageForm';


interface GalleryManagerProps {
  images: GalleryImage[];
//  setImages: (images: GalleryImage[]) => void; // Добавляем setter для изображений
  imageUrl: string;
  setImageUrl: (url: string) => void;          // Добавил setImageUrl для обновления
  onAddImage: (imageData: Omit<GalleryImage, 'id'>) => void;
  onReorder: (images: GalleryImage[]) => void;
  onDelete: (id: string) => void;
  onEdit: (image: GalleryImage) => void;
}

export function GalleryManager({
   images,
   //setImages,
   imageUrl,
   setImageUrl,
   onAddImage,
   onReorder,
   onDelete,
   onEdit
 }: GalleryManagerProps) {
  const [newImageUrl, setNewImageUrl] = useState('');
  const [newImageCaption, setNewImageCaption] = useState('');
  const [newImageAlt, setNewImageAlt] = useState('');

  // Следим за изменением imageUrl и обновляем newImageUrl
  useEffect(() => {
    if (imageUrl) {
      setNewImageUrl(imageUrl);
    }
  }, [imageUrl]);

  const handleAddImage = () => {
    if (!newImageUrl.trim()) return;

    const newImage = {
      url: newImageUrl,
      caption: newImageCaption,
      alt: newImageAlt || newImageCaption,
      width: 800,     // Примерное значение, можно заменить на динамическое
      height: 600,
      size: 100000,   // Примерное значение
      format: 'webp', // Формат по умолчанию
    };

    onAddImage(newImage); // Вызываем функцию добавления
    setNewImageUrl('');
    setNewImageCaption('');
    setNewImageAlt('');
    setImageUrl('');      // Очищаем после добавления
  };

  return (
      <div className="space-y-6">
        <div className="border rounded-lg p-4 space-y-4">
          <h3 className="text-lg font-medium text-gray-900">Добавить фото</h3>
          <ImageForm
              url={newImageUrl}
              caption={newImageCaption}
              alt={newImageAlt}
              onUrlChange={setNewImageUrl}
              onCaptionChange={setNewImageCaption}
              onAltChange={setNewImageAlt}
              onSubmit={handleAddImage}
              submitLabel="Добавить в галерею"
          />
        </div>

        <div className="border rounded-lg p-4">
          <h3 className="text-lg font-medium text-gray-900 mb-4">Изображения галереи</h3>
          <GalleryGrid
              images={images}
              onEdit={(img) => onEdit(img)}
              onDelete={(id) => onDelete(id)}
              onReorder={(dragIndex, dropIndex) => {
                const reorderedImages = [...images];
                const [draggedImage] = reorderedImages.splice(dragIndex, 1);
                reorderedImages.splice(dropIndex, 0, draggedImage);
                onReorder(reorderedImages);
                //            setImages(reorderedImages); // Обновляем состояние изображений
              }}
          />
        </div>
      </div>
  );
}